@@ -4,7 +4,7 @@ use warnings;
 
 package Stenciller::Standard {
 
-    our $VERSION = '0.1202'; # VERSION:
+    our $VERSION = '0.1205'; # VERSION:
     # ABSTRACT: Import to all
 
     use base 'Moops';
@@ -34,3 +34,38 @@ package Stenciller::Standard {
 }
 
 1;
+
+__END__
+
+=pod
+
+=encoding UTF-8
+
+=head1 NAME
+
+Stenciller::Standard - Import to all
+
+=head1 VERSION
+
+Version 0.1205, released 2015-01-18.
+
+=head1 SOURCE
+
+L<https://github.com/Csson/p5-Stenciller>
+
+=head1 HOMEPAGE
+
+L<https://metacpan.org/release/Stenciller>
+
+=head1 AUTHOR
+
+Erik Carlsson <info@code301.com>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2015 by Erik Carlsson <info@code301.com>.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
+=cut
